\vec{F} = m\vec{a} \nabla \cdot \vec{E} = \frac{\rho}{\varepsilon_0} G_{\mu\nu} + \Lambda g_{\mu\nu} = \frac{8\pi G}{c^4} T_{\mu\nu} (i\gamma^\mu \partial_\mu - m)\psi = 0 i\hbar\frac{\partial}{\partial t}\Psi(\mathbf{r}, t) = \hat{H}\Psi(\mathbf{r}, t) P(\text{16 out of 20}) = \frac{20!}{16! \times 4!} \times 0.85^{16} \times 0.15^{4} = 0.182122 \\P(\text{17 out of 20}) = \frac{20!}{17! \times 3!} \times 0.85^{17} \times 0.15^{3} = 0.242829 \\P(\text{18 out of 20}) = \frac{20!}{18! \times 2!} \times 0.85^{18} \times 0.15^{2} = 0.229338 \\P(\text{19 out of 20}) = \frac{20!}{19! \times 1!} \times 0.85^{19} \times 0.15^{1} = 0.136798 \\P(\text{20 out of 20}) = \frac{20!}{20! \times 0!} \times 0.85^{20} \times 0.15^{0} = 0.0387595 \begin{align*}P(\text{16 out of 20}) &= \frac{20!}{16! \times 4!} \times 0.85^{16} \times 0.15^{4} = 0.182122 \\P(\text{17 out of 20}) &= \frac{20!}{17! \times 3!} \times 0.85^{17} \times 0.15^{3} = 0.242829 \\P(\text{18 out of 20}) &= \frac{20!}{18! \times 2!} \times 0.85^{18} \times 0.15^{2} = 0.229338 \\P(\text{19 out of 20}) &= \frac{20!}{19! \times 1!} \times 0.85^{19} \times 0.15^{1} = 0.136798 \\P(\text{20 out of 20}) &= \frac{20!}{20! \times 0!} \times 0.85^{20} \times 0.15^{0} = 0.0387595\end{align*} \frac{d}{dx} f(x) \quad \text{versus} \quad \dv{f}{x} \frac{\partial}{\partial x} f(x,y) \quad \text{versus} \quad \pdv{f}{x} \vec{v} \quad \text{versus} \quad \vb{v} \quad \text{and} \quad \vec{v} \cdot \vec{w} \quad \text{versus} \quad \vb{v} \vdot \vb{w} \vec{\nabla} \phi \quad \text{versus} \quad \grad{\phi} \vec{\nabla} \cdot \vec{v} \quad \text{versus} \quad \div{\vb{v}} \vec{\nabla} \times \vec{v} \quad \text{versus} \quad \curl{\vb{v}} \langle \psi | \phi \rangle \quad \text{versus} \quad \braket{\psi}{\phi} [\hat{A}, \hat{B}] \quad \text{versus} \quad \comm{\hat{A}}{\hat{B}} \{\hat{A}, \hat{B}\} \quad \text{versus} \quad \acomm{\hat{A}}{\hat{B}} \begin{pmatrix}a & b \\c & d\end{pmatrix} \quad \text{versus} \quad \mqty(a & b \\ c & d) |\psi\rangle \quad \text{versus} \quad \ket{\psi} \langle\psi| \quad \text{versus} \quad \bra{\psi} \hat{H}|\psi\rangle \quad \text{versus} \quad \op{H}{\psi}